@@ -9,7 +9,7 @@ package org.mozilla.xpcom;
 
 public interface nsIDOMSVGSymbolElement extends nsIDOMSVGElement
 {
-  String NS_IDOMSVGSYMBOLELEMENT_IID =
+  public static final String NS_IDOMSVGSYMBOLELEMENT_IID =
     "{86092181-a5db-4a89-be03-07dcc14d426e}";
 
 }
